Coverage for apps.py: 100%

1 from django.apps import AppConfig

2

3

4 class DjangoCustomAdminPagesConfig(AppConfig):

5 name = "django_custom_admin_pages"

6

7 def ready(self):

8 # Load default settings when the app is ready

9 from django.conf import settings

10

11 from . import default_settings

12

13 for setting in dir(default_settings):

14 if not hasattr(settings, setting):

15 value = getattr(default_settings, setting)

16 setattr(settings, setting, value)